bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 8. Aventiure
___________________________________________________ #### Aventv wie Sifrit nah den Nibelungen #### sinen rechen fvor
| ### Sifrit der vil chvne dannen gie zehant ### siner tarnkappen da er daz schiffil vant ### dar an so stvnt vil tovgen daz Sigemvndes chint ### er fvrtez also balde sam ob ez wæte der wint ### Der vergen sach doch niemen wie serez schiffel vloz ### von Sifrides chreften di warn also groz ### man wande daz iz fvrte ein svnder starcher wint ### nein ez fvrte Sivrit der schonen Sigelinde kint
###### 495 | ### Bi des tages cite vn– in der einen naht ### chom er zeinem lande mit groezlicher maht ### daz hiez zen Nybelunge vn– wæren sine man ### lant vn– burge daz was im allez vndertan
###### 496 | ### Der herre fvr aleine vf einen wert vil breit ### daz schiff gebant vil balde der ritter vil gemeit ### do gie er zeinem berge da ein bvrch stvont ### er svhte herberge so noch die reismveden tvont
| ### Do chome er fvr die porten verslozzen im div stvnt ### ia hvten si <ir> eren so noch die lvten tvont ### anz tor begvnde bozen der vnchunde man ### daz was vil wol behvetet do vant er inrethaben dran
###### 498 | ### einen vngefuogen der der porten pflach ### bi dem sin gewæffen zallen citen lach ### der sprach wer ist der bozet vzen an daz tor ### do wandelt sine stimme der chvne Sivrit da vor
###### 499 | ### Er sprach ich bin ein reche entsliezet <vf> die tver ### mir mvz eteslicher volgen noch hivte der fver ### der gerne sanfte læge vnde hete sinen gemach ### do zvrnder portenære do daz Sifrit gesprach
| ### Nv het der rise chuone sin wæfen an sich genomen ### sin helm vf sin hovbet was im vil schiere chomen ### den schilt er balde zvchte daz tor er vf do swanch ### wie rehte gremliche er gegen Sivride spranch
###### 501 | ### Wie er getorste wechen so manigen chvenen man ### da wrde slege swinde von siner hant getan ### do begunde im schirmen der herliche gast ### do schvof der portenære daz sin schilt gespenge brast
###### 502 | ### von einer isen stangen des gie dem helde not ### ein teil begunde fvrhten Siurit den tot ### do der portenære so tobelichen slvoch ### dar vmbe was im wæge sin herre Sifrit genvoch
###### 503 | ### Si striten also sere daz al div bvrch erdoz ### wande ir beider sterche was vnmazen groz ### er twanc den portenære daz er in <sit> gebant ### do erschul[19v]len disiv mære vber al der Nibelunge lant
| ### Do hort daz grimme striten verre dvrch den berch ### Albrich der vil starche ein chvne getwerch ### er wart gewaffent balde do lief er da er vant ### disen gast vil edelen der was in beiden vil vnbechant
###### 505 | ### Albrich was vil grimme dar zvo starch genvoch ### helm vn– ringe er an dem libe trvoch ### vn– eine geisel swêre von golde an siner hant ### do lief er harte sere da er Sivriden vant
###### 506 | ### Siben knopfe sware die hiengen vor daran ### da mit er von den hende den schilt dem <kunen> man ### slvoch so bitterlichen daz im des vil zebrast ### des chom in groze sorge do der wætlich gast
###### 507 | ### Den scherm er von der hende gar zebrochen swanch ### do warfer von im balde sin wafen daz was lanch ### den sinen kamerære wolder niht slahen tot ### er schonte siner zvhte als im sin tvgent gebot
###### 508 | ### Mit starchen sinen handen lief er Albrichen an ### do vieng er bi dem parte den altgrisen man ### er zogeten vngefvge daz er vil lvot erscre ### zvht des ivngen rechen div tet Albriche we
###### 509 | ### Lvte rief der chvne nv lazzet mich genesen ### vn– moht ich iemens eigen an einen rechen wesen ### dem swor ich des eide ich wære im vndertan ### ich diende iv <e> ich stvrbe so sprach der listige man
| ### Do bant er Albrichen alsam den risen ê ### die Sifrides chrefte taten im vil we ### daz twerch begvnde vragen wie sint ir genant ### er sprach ich bin ez Sifrit ich wande ich wære iv wol bekant
###### 511 | ### So wol mich dirre mære sprach aber daz getwerch ### nv han ich wol erfvnden div degenlichen werch ### daz ir von waren schulden mvget landes herre wesn ### ich tvon swaz ir gebietet daz ir lazet mich genesn
###### 512 | ### Do sprach der herre Sifrit ir svlt balde gan ### vn– bringet mir der rechen der besten der wir han ### tvsint Nibelunge daz mich die hie gesehn ### was er der aller wolde des hort in niemen veriehn
###### 513 | ### Dem risen vn– Albrichen lost er do div bant ### do lief er harte balde da er die rechen vant ### er wacht in grozen <sorgen> vil manigen chvnen man ### er sprach wol vf ir helde ir sult zv Sifride gan
| ### Si sprungen von dem bette vn– waren vil bereit ### tvsint sneller degene wrden wol gekleit ### si chomen da si fvnden Sifriden stan ### da wart ein schone grvzen ein teil mit vorhten getan
###### 515 | ### Vil kercen wart enzvndet man schancht im luttertranch ### daz si so balde chomen des saget er in do danch ### er sprach ir mvzet hinnen mit mir vber flvot ### des vant er vil bereit die helde chven vn– gvot
###### 516 | ### Wol <driezech> hundert rechen die waren schiere komen ### vz den wrden tusint der besten <do> genomen ### den braht man ir helme vn– ander ir gewant ### do er si fveren wolde in daz Prvnhilde lant
###### 517 | ### Hort ir gvten ritter [20r]waz ich iv welle sagn ### ir svlt vil richiv chleider da ze hove tragen ### da wir sehen mvzen vi minnekliv wip ### dar vmbe svlt ir zieren mit gvter wæte den lip
###### 518 | ### Nv sprichet liht ein tvmber ez mach wol lvge wesen ### wie moehte so vil ritter bi ein ander sin genesn ### wa namen si die spise wa namen si gewant ### sine chvndenz niht verenden vn– ob in dienten drizzech lannt
###### 519 | ### Sivrit was so riche als ir wol habt gehort ### im diente daz chunichriche vn– Nibelunge hort ### des gaber sinen degenen vil vollechlich genvoch ### wande sin wart doch niht minre swie vil man von dem schatze
| ### Vil frvo an einem morgen hvben sie sih dan [ trvoch ### waz sneller geverten Sivrit do gewant ### si fvrten ros div gvten vn– herlich gewant ### si chomen ritterliche in daz Prvnhilt lant
###### 521 | ### Do stvnden in den venstern div minneklichen kint ### do sprach div kuniginne weiz iemen wer die sint ### die dort her gein vns vliezent so verre vf ienem se ### si fvrent segel riche die sint noch wizzer danne ein sne
###### 522 | ### Do sprach der vogt von Rine ez sint mine man ### die het ich an der verte hie nahe bi verlan ### die han ich besendet frowe die sint chomen ### der herlichen gesten wart vil groze war genomen
###### 523 | ### Do sach man Sifride vor in eime scheffe stan ### in vil herlicher wæte im volget manic man ### do sprach div kuniginne her chvnic ir svlt mir sagen ### sol ich die geste enpfahen oder sol ich grvzen si verdagen
###### 524 | ### Ir svlt in begegene sprach er miht zvhten gan ### ob wir si sehen gerne daz si wol daz versten ### do tet div kuniginne daz ir der kunic geriet ### Sifride mit dem grvoze von den andern si do schiet
###### 525 | ### Man schvof in herberge mit willen al zehant ### do was so vil der geste chomen in daz lant ### daz si sich allenthalben drvngen mit den scharn ### do wolden die vil chvenen zv den Burgonden varn
| ### Do hiez div kuniginne teilen sa zehant ### golt vn– silber ross vn– ovch gewant ### den vremden vn– den chvnden vil <manigem> werden man ### des ir <ir> vater hete nach sime tode vil verlan
###### 527 | ### Si hiez ovch sagen von Rine den rechen also her ### daz si des schazzes næmen minre oder mer ### daz si daz mit ir brêhten in Burgonden lant ### des antwrt ir Hagene in hohem mvte sa zehant
###### 528 | ### Vil edeliv kuniginne iv si fvr war geseit ### ez hat der kunic von Rine golt vn– kleit ### also vil ze gehene daz wir des habn rat ### daz wir iht hinnen fvren iwer golt oder iwer wat
###### 529 | ### Nein dvrch mine liebe sprach daz magedin ### ich wil mit mir hinnen <fveren> zweinzich schrin ### von golde vn– ovch siden daz gebn sol min hant ### so wir chomen vber in daz Gvntheres lant
| ### Do sprach div kuniginne wem laz ich miniv lant ### di sol nv hie bestiften vnser beider hant ### do sprach der kunic edele [20v]nv heizet her gan ### swer iv dar zvo gevalle den svln wir vogt wesn lan
###### 531 | ### Ein ir hohsten mage div frowe bi ir sach ### er was ir mvter brvder zv dem div maget sprach ### nv lat iv sin bevolhen die burge vn– ovch daz lant ### vnze daz hie rihte des kunich Guntheres hant
###### 532 | ### Do welt si ir gesindes tvsint chvner man ### die mit ir ze Rine solden varn dan ### zvo ienen tvsint rechen von Nibelunge lant ### si rihten sich zer verte man sach sie riten vf den sant
###### 533 | ### Si fvrten mit ir dannen sehs vn– ahzech wip ### dar zvo wol hvndert mægede vil schone was ir lip ### sine sovmten sich niht langer si ilten vaste dan ### die si da heime liezen hey was der weinen began
| ### In tvgentlichen zuohten si rvmt ir eigen lant ### si chvst ir frivnt die nehsten swaz si der bi ir vant ### mit gvtem vrlovbe si chomen vf den se ### zvo zir vater lande chome div frowe nimmer me
###### 535 | ### Do hort man vf der verte maniger hande spil ### aller kvrzewile der heten si vil ### do chome in zv zir reise ein rehter wazzerwint ### si fvren von dem lande vil harte vrolichen sint
###### 536 | ### Iane wolde si den herren niht minnen vf der vart ### er wart ir kurzwile vnz in sin hvs gespart ### ze Wormez zv der burge zeiner hochgecit ### dar si vil frevden riche chomen mit ir rechen sit

<<< Übersicht <<< vorige Seite nächste Seite >>>